@@ -4,7 +4,7 @@ use strict;
 use warnings;
 
 BEGIN {
-    $FuseBead::From::PNG::Const::VERSION = '0.01';
+    $FuseBead::From::PNG::Const::VERSION = '0.02';
 }
 
 require Exporter;
@@ -65,6 +65,12 @@ our @EXPORT_OK = qw(
     CHEDDER_RGB_COLOR_GREEN
     CHEDDER_RGB_COLOR_BLUE
 
+    CLEAR_NAME
+    CLEAR_HEX_COLOR
+    CLEAR_RGB_COLOR_RED
+    CLEAR_RGB_COLOR_GREEN
+    CLEAR_RGB_COLOR_BLUE
+
     CRANAPPLE_NAME
     CRANAPPLE_HEX_COLOR
     CRANAPPLE_RGB_COLOR_RED
@@ -329,6 +335,12 @@ our @EXPORT_OK = qw(
     TOOTHPASTE_RGB_COLOR_GREEN
     TOOTHPASTE_RGB_COLOR_BLUE
 
+    TURQUOISE_NAME
+    TURQUOISE_HEX_COLOR
+    TURQUOISE_RGB_COLOR_RED
+    TURQUOISE_RGB_COLOR_GREEN
+    TURQUOISE_RGB_COLOR_BLUE
+
     WHITE_NAME
     WHITE_HEX_COLOR
     WHITE_RGB_COLOR_RED
@@ -363,6 +375,7 @@ use constant BEAD_COLORS => qw(
     BUBBLEGUM
     BUTTERSCOTCH
     CHEDDER
+    CLEAR
     CRANAPPLE
     CREAM
     CYAN
@@ -407,6 +420,7 @@ use constant BEAD_COLORS => qw(
     SILVER
     TAN
     TOOTHPASTE
+    TURQUOISE
     WHITE
     YELLOW
 );
@@ -461,6 +475,12 @@ use constant {
     CHEDDER_RGB_COLOR_GREEN => 170,
     CHEDDER_RGB_COLOR_BLUE => 12,
 
+    CLEAR_NAME => 'Clear',
+    CLEAR_HEX_COLOR => 'D8D2CE',
+    CLEAR_RGB_COLOR_RED => 216,
+    CLEAR_RGB_COLOR_GREEN => 210,
+    CLEAR_RGB_COLOR_BLUE => 206,
+
     CRANAPPLE_NAME => 'Cranapple',
     CRANAPPLE_HEX_COLOR => '803245',
     CRANAPPLE_RGB_COLOR_RED => 128,
@@ -725,6 +745,12 @@ use constant {
     TOOTHPASTE_RGB_COLOR_GREEN => 200,
     TOOTHPASTE_RGB_COLOR_BLUE => 212,
 
+    TURQUOISE_NAME => 'Turquoise',
+    TURQUOISE_HEX_COLOR => '6797AE',
+    TURQUOISE_RGB_COLOR_RED => 103,
+    TURQUOISE_RGB_COLOR_GREEN => 151,
+    TURQUOISE_RGB_COLOR_BLUE => 174,
+
     WHITE_NAME => 'White',
     WHITE_HEX_COLOR => 'F1F1F1',
     WHITE_RGB_COLOR_RED => 241,
